Symbol

Struct Symbol 

pub struct Symbol(NonZero<u32>);
🔬This is a nightly-only experimental API. (proc_macro_internals)
Handle for a symbol string stored within the Interner.

Tuple Fields

0: NonZero<u32>
🔬This is a nightly-only experimental API. (proc_macro_internals)

Implementations

Source

impl Symbol

pub(crate) fn new(string: &str) -> Self

🔬This is a nightly-only experimental API. (proc_macro_internals)

Intern a new Symbol

pub(crate) fn new_ident(string: &str, is_raw: bool) -> Self

🔬This is a nightly-only experimental API. (proc_macro_internals)

Creates a new Symbol for an identifier.

Validates and normalizes before converting it to a symbol.

pub(crate) fn with<R>(self, f: impl FnOnce(&str) -> R) -> R

🔬This is a nightly-only experimental API. (proc_macro_internals)

Run a callback with the symbol’s string value.

pub(crate) fn invalidate_all()

🔬This is a nightly-only experimental API. (proc_macro_internals)

Clear out the thread-local symbol interner, making all previously created symbols invalid such that with will panic when called on them.

fn is_valid_ascii_ident(bytes: &[u8]) -> bool

🔬This is a nightly-only experimental API. (proc_macro_internals)

Checks if the ident is a valid ASCII identifier.

This is a short-circuit which is cheap to implement within the proc-macro client to avoid RPC when creating simple idents, but may return false for a valid identifier if it contains non-ASCII characters.

fn can_be_raw(string: &str) -> bool

🔬This is a nightly-only experimental API. (proc_macro_internals)